__version__ = "1.1.5"
__author__ = "Nemika"
__license__ = "MIT"
__name__ = "wolframalpha.py"

from .App import App
from .AsyncApp import AsyncApp
from . import errors